@@ -1,4 +1,4 @@
-PACKAGE = "ptrace"
-VERSION = "0.4"
+PACKAGE = "cptrace"
+VERSION = "0.6.1"
 WEBSITE = "http://python-ptrace.hachoir.org/"
 LICENSE = "GNU GPL v2"
