@@ -18,7 +18,8 @@ RUNNING_PYTHON3 = version_info[0] == 3
 RUNNING_PYPY = ("pypy" in version.lower())
 RUNNING_WINDOWS = (platform == 'win32')
 RUNNING_LINUX = (platform == 'linux2')
-RUNNING_FREEBSD = platform.startswith('freebsd')
+RUNNING_FREEBSD = (platform.startswith('freebsd')
+                   or platform.startswith('gnukfreebsd'))
 RUNNING_OPENBSD = platform.startswith('openbsd')
 RUNNING_MACOSX = (platform == 'darwin')
 RUNNING_BSD = RUNNING_FREEBSD or RUNNING_MACOSX or RUNNING_OPENBSD
